@@ -2,8 +2,8 @@
 
 '''
 Usually, the UI scripts are placed in directory ui and the related function \
-scripts are placed in directory _ui.
-Neither directory ui nor directory _ui is mandatory, take the easiest way.
+scripts are placed in directory ui_.
+Neither directory ui nor directory ui_ is mandatory, take the easiest way.
 '''
 
 import getopt
@@ -16,7 +16,7 @@ from pathlib import Path
 import yaml
 from appdirs import user_data_dir
 
-__version__ = version = "0.2.44"
+__version__ = version = "0.2.46"
 __appname__ = appname = 'Funing'
 __appauthor__ = appauthor = 'Larry & Contributors'
 
@@ -38,6 +38,7 @@ faces_path = \
     os.path.join(user_data_path, 'faces')
 infos_path = \
     os.path.join(user_data_path, 'infos')
+data_path = os.path.join(user_data_path, 'data')
 
 user_ipynb_dir_path = \
     os.path.join(user_data_path, 'ipynb')
@@ -60,10 +61,17 @@ prev_version = \
 backup_path = \
     os.path.join(user_data_path, '.cp')
 
-user_dirs = [faces_path, infos_path, backup_path, user_ipynb_dir_path]
+user_dirs = [
+    faces_path,
+    infos_path,
+    backup_path,
+    user_ipynb_dir_path,
+    data_path]
 for p in user_dirs:
     os.path.exists(p) or os.makedirs(p)
 
+info_file_name = 'info.toml'
+
 os.path.exists(user_ipynb_path) or \
     shutil.copyfile(project_ipynb_path, user_ipynb_path)
 os.path.exists(example_ipynb_path) or \
@@ -77,7 +85,7 @@ elif prev_version != __version__:
         yaml.safe_dump(config_yml, f)
 
 
-def data_empty(): return len(os.listdir(faces_path)) < 1
+def data_empty(): return len(os.listdir(data_path)) < 1
 
 
 start_args = ['s', 'st' 'start']
@@ -85,5 +93,5 @@ test_args = ['ts', 't', 'test']
 
 
 def simple():
-    from funing._ui import _main_ui
-    _main_ui._MainUI()
+    from funing._ui import main
+    main.start()
